from setuptools import setup, find_packages


setup(
    name='Class',

    version='1.1.0',

    description='',
    long_description='',

    author='Yohei Akita, nabe, miso',
    author_email='akita.yohei0724@gmail.com',

    license='GPL v2.0',

    packages=find_packages()
)
